@@ -1,7 +1,7 @@
 """Longest Common Subsequence alignments."""
 
 
-from .all_lcs import edit, lcs_graph, to_dot, traversal
+from .all_lcs import edit, lcs_graph, traversal
 from .distance_only import edit as edit_distance_only
 
 
@@ -9,6 +9,5 @@ __all__ = [
     "edit",
     "edit_distance_only",
     "lcs_graph",
-    "to_dot",
     "traversal",
 ]
