@@ -1,9 +1,9 @@
 """Relation class and functions to compare variants.
 
 Calculate the relation between two variants using the definitions
-from [1]_. Variants are given as observed sequences (alleles), i.e., a
-list of variants applied to some reference sequence. Both variants
-subject to the same reference sequence.
+from [1]_. Variants are given as alleles, i.e., a list of variants
+applied to some reference sequence. Both variants subject to the same
+reference sequence.
 
 References
 ----------
