@@ -4,7 +4,7 @@
 from itertools import chain
 import random
 from . import Variant
-from .variants import DNA_NUCLEOTIDES
+from .variants import DNA_NUCLEOTIDES, to_hgvs
 
 
 def canonical(variants, max_distance=40):
@@ -24,11 +24,29 @@ def fasta_sequence(lines):
 
 def vcf_variant(line):
     """Create a variant from a (simple) VCF line."""
-    _, position, _,  deleted, inserted, *_ = line.split()
+    _, position, _, deleted, inserted, *_ = line.split()
     start = int(position) - 1
     return Variant(start, start + len(deleted), inserted)
 
 
+def to_dot(reference, root):
+    """The LCS graph in Graphviz DOT format."""
+    def traverse():
+        # breadth-first traversal
+        visited = {root}
+        queue = [root]
+        while queue:
+            node = queue.pop(0)
+            for succ, variant in node.edges:
+                yield (f'"{node.row}_{node.col}" -> "{succ.row}_{succ.col}"'
+                       f' [label="{to_hgvs(variant, reference)}"];')
+                if succ not in visited:
+                    visited.add(succ)
+                    queue.append(succ)
+
+    return "digraph {\n    " + "\n    ".join(traverse()) + "\n}"
+
+
 def random_sequence(max_length, min_length=0, alphabet=DNA_NUCLEOTIDES, weights=None):
     """Create a random sequence.
 
