@@ -2,12 +2,14 @@
 
 
 from .parser import Parser
-from .variant import Variant, patch, to_hgvs
+from .variant import DNA_NUCLEOTIDES, Variant, patch, reverse_complement, to_hgvs
 
 
 __all__ = [
+    "DNA_NUCLEOTIDES",
     "Parser",
     "Variant",
     "patch",
+    "reverse_complement",
     "to_hgvs",
 ]
